@@ -1,11 +1,11 @@
 #!/usr/bin/env python
 
-import urlparse
+import urllib.parse
 import hmac
 
 from hashlib import sha1
 from base64 import b64encode
-from swagger import RequestSigner, ApiClient
+from .swagger import RequestSigner, ApiClient
 
 
 class GroupDocsRequestSigner(RequestSigner):
@@ -14,7 +14,7 @@ class GroupDocsRequestSigner(RequestSigner):
         self.privateKey = privateKey
         
     def signUrl(self, url):
-        urlParts = urlparse.urlparse(url)
+        urlParts = urllib.parse.urlparse(url)
         pathAndQuery = urlParts.path + ('?' + urlParts.query if urlParts.query else urlParts.query)
         signed = hmac.new(self.privateKey.encode('utf-8'), ApiClient.encodeURI(pathAndQuery).encode('utf-8'), sha1)
         signature = b64encode(signed.digest()).decode('utf-8')
